pub fn accept<V>(value: V) -> Attr<Accept, V>where
V: AttributeValue,Expand description
The accept attribute specifies a list of types the server accepts, typically a file type.
pub fn accept<V>(value: V) -> Attr<Accept, V>where
V: AttributeValue,The accept attribute specifies a list of types the server accepts, typically a file type.