pub fn controls<V>(value: V) -> Attr<Controls, V>where
V: AttributeValue,Expand description
The controls attribute indicates whether the browser should display playback controls for the media.
pub fn controls<V>(value: V) -> Attr<Controls, V>where
V: AttributeValue,The controls attribute indicates whether the browser should display playback controls for the media.