pub fn draggable<V>(value: V) -> Attr<Draggable, V>where
V: AttributeValue,Expand description
The draggable attribute indicates whether the element is draggable.
pub fn draggable<V>(value: V) -> Attr<Draggable, V>where
V: AttributeValue,The draggable attribute indicates whether the element is draggable.