pub fn notation<V>(value: V) -> Attr<Notation, V>where
V: AttributeValue,Expand description
The notation attribute specifies the type of notation for the element.
pub fn notation<V>(value: V) -> Attr<Notation, V>where
V: AttributeValue,The notation attribute specifies the type of notation for the element.