pub fn onload<V>(value: V) -> Attr<Onload, V>where
V: AttributeValue,Expand description
The onload attribute specifies the event handler for the load event.
pub fn onload<V>(value: V) -> Attr<Onload, V>where
V: AttributeValue,The onload attribute specifies the event handler for the load event.