pub fn open<V>(value: V) -> Attr<Open, V>where
V: AttributeValue,Expand description
The open attribute indicates whether the details element is open or closed.
pub fn open<V>(value: V) -> Attr<Open, V>where
V: AttributeValue,The open attribute indicates whether the details element is open or closed.