Cursor

Struct Cursor 

pub struct Cursor(/* private fields */);
Hydration works by walking over the DOM, adding interactivity as needed.

This cursor tracks the location in the DOM that is currently being hydrated. Each that type implements RenderHtml knows how to advance the cursor to access the nodes it needs.

Implementations

Source

impl Cursor
where Element: AsRef<Node>,

pub fn new(root: Element) -> Self

Creates a new cursor starting at the root element.

pub fn current(&self) -> Node

Returns the node at which the cursor is currently located.

pub fn child(&self)

Advances to the next child of the node at which the cursor is located.

Does nothing if there is no child.

pub fn sibling(&self)

Advances to the next sibling of the node at which the cursor is located.

Does nothing if there is no sibling.

pub fn parent(&self)

Moves to the parent of the node at which the cursor is located.

Does nothing if there is no parent.

pub fn set(&self, node: Node)

Sets the cursor to some node.

pub fn next_placeholder(&self, position: &PositionState) -> Placeholder

Advances to the next placeholder node and returns it

pub fn advance_to_placeholder(&self, position: &PositionState)

Advances to the next placeholder node.