pub struct Cursor(/* private fields */);Expand description
Hydration works by walking over the DOM, adding interactivity as needed.
This cursor tracks the location in the DOM that is currently being hydrated. Each that type
implements RenderHtml knows how to advance the cursor to access
the nodes it needs.
Implementations
Sourceimpl Cursor
impl Cursor
Sourcepub fn child(&self)
pub fn child(&self)
Advances to the next child of the node at which the cursor is located.
Does nothing if there is no child.
Sourcepub fn sibling(&self)
pub fn sibling(&self)
Advances to the next sibling of the node at which the cursor is located.
Does nothing if there is no sibling.
Sourcepub fn parent(&self)
pub fn parent(&self)
Moves to the parent of the node at which the cursor is located.
Does nothing if there is no parent.
Sourcepub fn next_placeholder(&self, position: &PositionState) -> Placeholder
pub fn next_placeholder(&self, position: &PositionState) -> Placeholder
Advances to the next placeholder node and returns it
Sourcepub fn advance_to_placeholder(&self, position: &PositionState)
pub fn advance_to_placeholder(&self, position: &PositionState)
Advances to the next placeholder node.